<?php

// Reminder: always indent with 4 spaces (no tabs). 
// +---------------------------------------------------------------------------+
// |                                                                           |
// | Rating Plugin for Geeklog                                                 |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | config.inc                                                                |
// |                                                                           |
// | config file for the Rating plugin for Geeklog.                            |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | Copyright  (C) 2006 Euan McKay  - info AT heatherengineering DOT com      |
// | Copyright  (C) 2006 Tom Homer	 - TomHomer AT cogeco DOT com              |
// | For support and information, visit http://www.heatherengineering.com/     |
// |                                                                           |
// +---------------------------------------------------------------------------+
// | Based on the Universal Plugin and prior work by the following authors:    |
// |                                                                           |
// | Copyright (C) 2002-2006 by the following authors:                         |
// |                                                                           |
// | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
// |          Tom Willett       - tom AT pigstye DOT net                       |
// |          Blaine Lang       - blaine AT portalparts DOT com                |
// |          Dirk Haun         - dirk AT haun-online DOT de                   |
// |          Vincent Furia     - vinny01 AT users DOT sourceforge DOT net     |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

// ****************************************************************
// Defined Flag values for Rating Function Flags (Auto Tag Flag, etc..)
// See RATING_function_in_flag in functions.inc if adding constants
// DO NOT CHANGE names, values or order
// ****************************************************************
define("CONST_FLAG_MAX", 11); // Used by function (do not include default flag)
define("CONST_MAX_CONSTANT_VALUE", 1024); // Used by function (do not include default flag in count)

define("CONST_FLAG_DEFAULT_RATING", 0); // Default settings, allows older versions of Rating Plugin to work

define("CONST_FLAG_RATING_AS_STARS", 1); // Display Rating as Stars
define("CONST_FLAG_RATING_AS_TEXT", 2);  // Display Rating as Text

define("CONST_FLAG_SHOW_TOTALS", 4);  		// Show existing user rating
define("CONST_FLAG_SHOW_LABEL", 8);  		// Show Average Text

define("CONST_FLAG_REVIEWS_VIEW", 16);			// Show Review Button (if any exist)
define("CONST_FLAG_REVIEWS_ADD", 32);			// Show Add review button

define("CONST_FLAG_RATING_VIEW", 64);			// Rating is a view only (No Adding)
define("CONST_FLAG_RATE_AS_TEXT", 128);		// User Rating interface as text ([1] [2] [3] ...)
define("CONST_FLAG_RATE_AS_STARS", 256);	// User Rating interface as stars
define("CONST_FLAG_RATE_AS_COMBO", 512);	// User Rating interface as a dropdown list and save button

define("CONST_FLAG_RATING_AS_DIGG", 1024);	// DIGG type rating

// ****************************************************************

/**
* the rating plugin's config aray
* 
* @global array $_RATING_CONF 
*/
$_RATING_CONF = array();

/**
* the rating plugin's version setting
* 
* @global array $_RATING_CONF['version']
*/
$_RATING_CONF['version'] = '2.3.1';          // Plugin Version

/**
 * Set to 1 to hide a section from the What's New block:
 * 
 * @global array $_RATING_CONF['hidenewrating']
 */ 
$_RATING_CONF['hidenewrating'] = 0;

/**
 * Set to 1 to show Ratings Menu Item:
 * 
 * @global array $_RATING_CONF['hideratingmenu']
 */ 

$_RATING_CONF['hideratingmenu'] = 0;

/**
 * Following times are in seconds
 * 
 * @global array $_RATING_CONF['newratinginterval']
 */ 
$_RATING_CONF['newratinginterval']    = 1209600; // = 14 days

/**
 * should we remove ratings submited by users if account is removed? (1)
 * or change owner to anonymous with IP address 0.0.0.0 (0)
 * 
 * @global array $_RATING_CONF['delete_ratings']
 */ 
$_RATING_CONF['delete_ratings'] = 0; 

/**
 * notify when a new rating/review was submitted for approval
 * 
 * @global array $_RATING_CONF['notification']
 */ 
$_RATING_CONF['submission_notification'] = 1; 

/**
 * show (1) or hide (0) rating averages to users before/after they vote
 * 
 * @global array $_RATING_CONF['showaverages']
 */ 
$_RATING_CONF['show_averages_before'] = 1;
$_RATING_CONF['show_averages_after'] = 1;

/**
 * brackets etc for numbered text links to use when rating an item
 * 
 */ 
$_RATING_CONF['before'] = '[&nbsp;';
$_RATING_CONF['middle']   = '&nbsp;&#183;&nbsp;'; // If left blank will not use and just use before and after around each number
$_RATING_CONF['after']   = '&nbsp;]';

/**
 * show (CONST_FLAG_SHOW_TOTALS) or hide (0) a user's own rating for an item default.
 * 
 * @global array $_RATING_CONF['story_comments']
 */ 
$_RATING_CONF['show_user_rating_default_display'] = CONST_FLAG_REVIEWS_ADD;

/**
 * show user rating (refering to the info Your Rating:) as: CONST_FLAG_RATING_AS_TEXT, CONST_FLAG_RATING_AS_STARS
 * 
 * @global array $_RATING_CONF['user_rating_default_display']
 */ 
$_RATING_CONF['user_rating_default_display'] = CONST_FLAG_RATING_AS_STARS;

/**
 * show user rating & reviews (refering to the info Your Rating:) as: CONST_FLAG_RATING_AS_TEXT, CONST_FLAG_RATING_AS_STARS 
 * 
 * @global array $_RATING_CONF['user_review_default_display']
 */ 
$_RATING_CONF['user_review_default_display'] = CONST_FLAG_RATING_AS_STARS;

/**
 * show average of user ratings for items: CONST_FLAG_RATING_AS_TEXT, CONST_FLAG_RATING_AS_STARS
 * 
 * @global array $_RATING_CONF['average_rating_default_display']
 */ 
$_RATING_CONF['average_rating_default_display'] = CONST_FLAG_RATING_AS_STARS;

/**
 * show links to click, for rating an item: CONST_FLAG_RATE_AS_COMBO, CONST_FLAG_RATE_AS_TEXT , CONST_FLAG_RATE_AS_STARS
 * 
 * @global array $_RATING_CONF['rating_interface_default_display']
 */ 
$_RATING_CONF['rating_interface_default_display'] = CONST_FLAG_RATE_AS_COMBO;

// Use Image Buttons for submitting ratings/diggs/review instead of normal buttons
$_RATING_CONF['use_image_buttons'] = '0';

// Default scores if none exist
$_RATING_CONF['score_min'] = 1; // Should always be one
$_RATING_CONF['score_max'] = 5; // If set to 1 (the same with min) then a Digg type rating is assumed

/**
 * show (1) or hide (0) a user's own rating for an item
 * Must add the tag {rating) to the profile.thtml template
 * in the users directory of your layout for it to show.
 * 
 * @global array $_RATING_CONF['rate_users']
 */ 
$_RATING_CONF[rate_users] = 0; // Allow (1) or disallow (0) rating of users
$_RATING_CONF[rate_users_min] = 1; // Min value of rating
$_RATING_CONF[rate_users_max] = 5; // Max value of rating
$_RATING_CONF[rate_users_function_flag] = CONST_FLAG_DEFAULT_RATING;  // Rating Function flag, see Function flag for AutoTags

// Diggs Center Block Enabled
$_RATING_CONF['diggs_center_block'] = 0;
$_RATING_CONF['diggs_home_page_only'] = 1; // 0 all pages or 1 homepage 
$_RATING_CONF['diggs_center_block_where'] = 1; // 1 - Above Featured Article, 2 - Below Featured Article, 3 - Bottom of Page
$_RATING_CONF['number_diggs_center_block'] = 10;
$_RATING_CONF['new_digg_interval'] = 7; // In days
$_RATING_CONF['digg_max_topic_size'] = 40; // Stories max title size is 128
$_RATING_CONF['digg_date_format'] = '%m/%d/%y %H:%M %p';

$_RATING_CONF['rate_own_item'] = 1;           // Allow (1) or Disallow (0) users to rate/review/digg their own item (or who ever owns the Parent Object. Only supports story, user, staticpage and comments.)
$_RATING_CONF['ratingloginrequired'] = 0;			// 1 = required, 0 not required (therefore anonymous user can rate)
$_RATING_CONF['ratingspeedlimit'] = 15;        // minimum time between review posts, in seconds
$_RATING_CONF['ratingorder'] = 'DESC';					// ASC or DESC
$_RATING_CONF['ratinglimit'] = 6;							// # of reviews per page

// Owner of all auto created items (ie User Ratings and if you have automatically created ratings for stories, etc..
// Should leave as Admin which is user 2 on default installs
$_RATING_CONF['rating_owner_auto_created'] = 2;

// database table names - don't change
$_TABLES['rating']       = $_DB_table_prefix . 'rating';
$_TABLES['ratingsubmission']       = $_DB_table_prefix . 'ratingsubmission';
$_TABLES['rating_totals']      = $_DB_table_prefix . 'rating_totals';

/**
 * Define default permissions for new rating totals and new ratings/reviews created from the Admin panel.
 * Permissions are perm_owner, perm_group, perm_members, perm_anon (in that
 * order). Possible values:<br>
 * - 3 = read + write permissions (perm_owner and perm_group only)
 * - 2 = read-only
 * - 0 = neither read nor write permissions
 * (a value of 1, ie. write-only, does not make sense and is not allowed)
 * 
 * @global array $_LI_CONF['default_permissions']
perm_owner = rights owner has over item (usually 3, meaning read/write)
perm_group = rights group has over item (often 3, meaning read/write)
perm_members = rights logged in users have over item (usually 1, meaning read only)
perm_anon = rights anonymous users have over item (usually 0, meaning nothing, or 1, meaning read only)
*/ 
 
$_RATING_CONF['default_permissions_totals'] = array (3, 2, 2, 2); // Permissions for the Rating Totals Item itself
$_RATING_CONF['default_permissions_ratings'] = array (2, 2, 2, 2); // Permissions for the actual users rating/review/digg 

// For paypal plugin
$_RATING_CONF['rating_type_paypal'] = 'paypal';
$_RATING_CONF['rating_type_paypal_url'] = '/' . $_PAY_CONF['paypal_folder'] . '/product_detail.php?product=';
$_RATING_CONF['rating_type_paypal_title']  = "SELECT name FROM " . $_TABLES['paypal_products'] . " WHERE id=";

?>